Page 63 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 63

Home

    helpful to consider the background of the Founding
    Fathers themselves, the most common denominator being
    their Christian Faith. This is not something attributed to
    them by others, but something established by their own
    writings and background. Out of the fifty-five delegates
    to the Constitutional Convention, Christianity was the

    religion of at least fifty. This means that 90 percent of the
    delegates were Christians. For an excellent 415 page
    book covering this subject, we recommend Christianity
    And The Constitution by John Eidsmoe published by
    Baker Book House, Grand Rapids, Michigan. To learn
    the truth about the beliefs of the Founding Fathers,
    Eidsmoe personally read 5,000 letters written by these

    men.

    Not only were the Founding Fathers well versed in
    Scripture, they were also well educated in history. One
    thing that made the founding of the American Republic
    possible was the high rate of literacy and high standard
    of education among the colonists. Eidsmoe gives us an
    idea of this level:

    The high caliber of learning at that time is evident
    from the entrance requirements for colonial colleges. In
    the 1700s an undergraduate freshman at William and
    Mary College had to be able to read, write, converse,
    and debate in Greek. When John Jay applied for
    admission to King's College in New York at the age of
    fourteen, one of the entrance requirements he had to
    fulfill was to translate the first ten chapters of the Gospel
    of John from Greek into Latin.”

    58

    The Secret Side of History